RoundRobinStrategy

Struct RoundRobinStrategy 

pub struct RoundRobinStrategy { /* private fields */ }
Cycles through healthy proxies in order, distributing load evenly.

Uses a lock-free AtomicUsize counter, so no Mutex is needed even under high concurrency.

Example

use stygian_proxy::strategy::{RoundRobinStrategy, RotationStrategy, ProxyCandidate};
use stygian_proxy::types::ProxyMetrics;
use std::sync::Arc;
use uuid::Uuid;

let strategy = RoundRobinStrategy::default();
let candidates = vec![
    ProxyCandidate { id: Uuid::new_v4(), weight: 1, metrics: Arc::new(ProxyMetrics::default()), healthy: true },
    ProxyCandidate { id: Uuid::new_v4(), weight: 1, metrics: Arc::new(ProxyMetrics::default()), healthy: true },
];
let a = strategy.select(&candidates).await.unwrap().id;
let b = strategy.select(&candidates).await.unwrap().id;
assert_ne!(a, b, "round-robin should alternate between two proxies");